Data Types
==========

.. automodule:: stonesoup.types
    :no-members:

Base Types
----------

.. automodule:: stonesoup.types.base
    :show-inheritance:

Array Types
-----------

.. automodule:: stonesoup.types.array
    :show-inheritance:

Detection Types
---------------

.. automodule:: stonesoup.types.detection
    :show-inheritance:

Ground Truth Types
------------------

.. automodule:: stonesoup.types.groundtruth
    :show-inheritance:

Hypothesis Types
----------------

.. automodule:: stonesoup.types.hypothesis
    :show-inheritance:

.. automodule:: stonesoup.types.multihypothesis
    :show-inheritance:

Metric Types
------------

.. automodule:: stonesoup.types.metric
    :show-inheritance:

Numeric Types
-------------

.. automodule:: stonesoup.types.numeric
    :show-inheritance:

Particle Types
--------------

.. automodule:: stonesoup.types.particle
    :show-inheritance:

Prediction Types
----------------

.. automodule:: stonesoup.types.prediction
    :show-inheritance:

Sensor Data Types
-----------------

.. automodule:: stonesoup.types.sensordata
    :show-inheritance:

State Types
-----------

.. automodule:: stonesoup.types.state
    :show-inheritance:
    :inherited-members: stonesoup.types.state.StateMutableSequence

Time Types
----------------

.. automodule:: stonesoup.types.time
    :show-inheritance:

Track Types
-----------

.. automodule:: stonesoup.types.track
    :show-inheritance:

Update Types
------------

.. automodule:: stonesoup.types.update
    :show-inheritance:


